## 0.0.37 - 2025-04-04

* [REFACTOR] adding box AI api multiple file dupport (f88be7b)
* [REFACTOR] adding box AI api multiple file dupport (1b98433)
* [REFACTOR] adjusting imports (d693c1b)
* Update version to 0.0.36 and changelog (2cc5134)